aboutsummaryrefslogtreecommitdiff
path: root/gcc
diff options
context:
space:
mode:
authorJakub Jelinek <jakub@redhat.com>2010-05-07 17:47:52 +0200
committerJakub Jelinek <jakub@gcc.gnu.org>2010-05-07 17:47:52 +0200
commit86b2c5b637642a064406be4c02bf107ce338b8c5 (patch)
treec93879af013252e30773946c72c0726b13d6a101 /gcc
parentdb7d7dc1730d47f5813940d97ca60cd6ffa4e2eb (diff)
downloadgcc-86b2c5b637642a064406be4c02bf107ce338b8c5.zip
gcc-86b2c5b637642a064406be4c02bf107ce338b8c5.tar.gz
gcc-86b2c5b637642a064406be4c02bf107ce338b8c5.tar.bz2
tree.h (TREE_ADDRESSABLE): Adjust comment to say that this is also meaningful on PARM_DECLs and RESULT_DECLs.
* tree.h (TREE_ADDRESSABLE): Adjust comment to say that this is also meaningful on PARM_DECLs and RESULT_DECLs. From-SVN: r159156
Diffstat (limited to 'gcc')
-rw-r--r--gcc/ChangeLog5
-rw-r--r--gcc/tree.h7
2 files changed, 9 insertions, 3 deletions
diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 3cc8d2b..c7013c3 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,8 @@
+2010-05-07 Jakub Jelinek <jakub@redhat.com>
+
+ * tree.h (TREE_ADDRESSABLE): Adjust comment to say that
+ this is also meaningful on PARM_DECLs and RESULT_DECLs.
+
2010-05-07 Rainer Orth <ro@CeBiTec.Uni-Bielefeld.DE>
* config/mips/iris6.h (LINK_SPEC): Don't pass -init, -fini with -r.
diff --git a/gcc/tree.h b/gcc/tree.h
index 4e5ef70..a03ede5 100644
--- a/gcc/tree.h
+++ b/gcc/tree.h
@@ -411,7 +411,8 @@ struct GTY(()) tree_common {
addressable_flag:
TREE_ADDRESSABLE in
- VAR_DECL, FUNCTION_DECL, FIELD_DECL, LABEL_DECL
+ VAR_DECL, PARM_DECL, RESULT_DECL, FUNCTION_DECL, FIELD_DECL
+ LABEL_DECL
all types
CONSTRUCTOR, IDENTIFIER_NODE
STMT_EXPR, it means we want the result of the enclosed expression
@@ -1106,8 +1107,8 @@ extern void omp_clause_range_check_failed (const_tree, const char *, int,
/* Define many boolean fields that all tree nodes have. */
-/* In VAR_DECL nodes, nonzero means address of this is needed.
- So it cannot be in a register.
+/* In VAR_DECL, PARM_DECL and RESULT_DECL nodes, nonzero means address
+ of this is needed. So it cannot be in a register.
In a FUNCTION_DECL, nonzero means its address is needed.
So it must be compiled even if it is an inline function.
In a FIELD_DECL node, it means that the programmer is permitted to